@@ -2,8 +2,11 @@ use std::fmt::Display;
 
 use pyo3::prelude::*;
 
+use stack_graphs::storage::SQLiteReader;
 use tree_sitter_stack_graphs::cli::util::{SourcePosition, SourceSpan};
 
+use crate::stack_graphs_wrapper::query_definition;
+
 #[pyclass]
 #[derive(Clone)]
 pub enum Language {
@@ -24,6 +27,37 @@ pub struct Position {
     column: usize,
 }
 
+#[pyclass]
+pub struct Querier {
+    db_reader: SQLiteReader,
+}
+
+#[pymethods]
+impl Querier {
+    #[new]
+    pub fn new(db_path: String) -> Self {
+        println!("Opening database: {}", db_path);
+        Querier {
+            db_reader: SQLiteReader::open(db_path).unwrap(),
+        }
+    }
+
+    pub fn definitions(&mut self, reference: Position) -> PyResult<Vec<Position>> {
+        let result = query_definition(reference.into(), &mut self.db_reader)?;
+
+        let positions: Vec<Position> = result
+            .into_iter()
+            .map(|r| r.targets)
+            .flatten()
+            .map(|t| t.into())
+            .collect();
+
+        Ok(positions)
+    }
+}
+
+// TODO(@nohehf): Indexer class
+
 #[pymethods]
 impl Position {
     #[new]
